{% with instance.meta_image as meta_image %}

<meta name="twitter:card" content="{{global_settings.card_type}}">
<meta name="twitter:title" content="{{page.title}}">
<meta name="twitter:description" content="{{instance.meta_description}}">
<meta name="twitter:image" content="{{meta_image.full_url}}">

<meta property="og:url" content="{{page.absolute_url}}" />
<meta property="og:title" content="{{page.title}}" />
<meta property="og:description" content="{{instance.meta_description}}" />
<meta property="og:site_name" content="{{site_name}}" />
<meta property="og:image" content="{{meta_image.full_url}}" />

<meta itemprop='url' content='{{page.absolute_url}}'/>
<meta itemprop="name" content="{{page.title}}">
<meta itemprop='description' content='{{instance.meta_description}}' />
<meta itemprop='image' content='{{meta_image.full_url}}' />

<meta name="description" content="{{instance.meta_description}}">
{% endwith %}
